# Generated by Django 4.0.8 on 2022-12-22 01:51

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0078_characterwalletjournalentry_corptools_c_date_aebcea_idx_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='characteraudit',
            name='last_update_location',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
        migrations.CreateModel(
            name='CharacterLocation',
            fields=[
                ('id', models.AutoField(auto_created=True,
                 primary_key=True, serialize=False, verbose_name='ID')),
                ('character', models.OneToOneField(
                    on_delete=django.db.models.deletion.CASCADE, to='corptools.characteraudit')),
                ('current_location', models.ForeignKey(blank=True, default=None, null=True,
                 on_delete=django.db.models.deletion.CASCADE, to='corptools.evelocation')),
                ('current_ship', models.ForeignKey(blank=True, default=None, null=True,
                 on_delete=django.db.models.deletion.CASCADE, to='corptools.eveitemtype')),
            ],
        ),
    ]
