# Generated by Django 2.2.9 on 2020-05-08 15:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0005_auto_20200508_1506'),
    ]

    operations = [
        migrations.AddField(
            model_name='invtypematerials',
            name='type_id',
            field=models.IntegerField(default=0),
            preserve_default=False,
        ),
    ]
