# Generated by Django 2.2.12 on 2020-08-14 10:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0027_skilllistfile'),
    ]

    operations = [
        migrations.DeleteModel(
            name='SkillListFile',
        ),
    ]
