# Generated by Django 4.2.5 on 2023-10-02 10:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0093_alter_characteraudit_options'),
    ]

    operations = [
        migrations.CreateModel(
            name='LastLoginfilter',
            fields=[
                ('id', models.AutoField(auto_created=True,
                 primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=500)),
                ('description', models.CharField(max_length=500)),
                ('days_since_login', models.IntegerField(
                    default=30, help_text="Days since last login of any Character in the accounts Main's Corporation to pass filter.")),
                ('no_data_pass', models.BooleanField(blank=True, default=False,
                 help_text='If there is no data (No Valid Corp Token) for a characters account then should this filter automatically pass.')),
            ],
            options={
                'verbose_name': 'Smart Filter: Last Login Check',
                'verbose_name_plural': 'Smart Filter: Last Login Check',
            },
        ),
        migrations.AddField(
            model_name='characteraudit',
            name='last_known_login',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='characteraudit',
            name='last_known_logoff',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='characteraudit',
            name='last_update_login',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='corporationaudit',
            name='last_update_known_login',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
    ]
