# Generated by Django 3.1.1 on 2021-01-12 04:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0038_auto_20210112_0102'),
    ]

    operations = [
        migrations.AddField(
            model_name='assetsfilter',
            name='eve_groups',
            field=models.ManyToManyField(
                blank=True, to='corptools.EveItemGroup'),
        ),
        migrations.AlterField(
            model_name='assetsfilter',
            name='eve_types',
            field=models.ManyToManyField(
                blank=True, to='corptools.EveItemType'),
        ),
    ]
