# Generated by Django 2.2.13 on 2020-06-22 06:43

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0015_auto_20200614_0935'),
    ]

    operations = [
        migrations.RenameField(
            model_name='oretaxrates',
            old_name='r8',
            new_name='common_rate',
        ),
        migrations.RenameField(
            model_name='oretaxrates',
            old_name='r64',
            new_name='excptional_rate',
        ),
        migrations.RenameField(
            model_name='oretaxrates',
            old_name='r0',
            new_name='ore_rate',
        ),
        migrations.RenameField(
            model_name='oretaxrates',
            old_name='r32',
            new_name='rare_rate',
        ),
        migrations.RenameField(
            model_name='oretaxrates',
            old_name='r4',
            new_name='ubiquitous_rate',
        ),
        migrations.RenameField(
            model_name='oretaxrates',
            old_name='r16',
            new_name='uncommon_rate',
        ),
        migrations.AddField(
            model_name='miningtax',
            name='flat_tax_rate',
            field=models.DecimalField(
                blank=True, decimal_places=2, default=None, max_digits=5, null=True),
        ),
        migrations.AddField(
            model_name='structure',
            name='last_online_time',
            field=models.DateTimeField(default=None, null=True),
        ),
        migrations.AlterField(
            model_name='miningtax',
            name='tax_rate',
            field=models.ForeignKey(blank=True, default=None, null=True,
                                    on_delete=django.db.models.deletion.CASCADE, to='corptools.OreTaxRates'),
        ),
        migrations.AlterField(
            model_name='oretaxrates',
            name='tag',
            field=models.CharField(default='Mining Tax', max_length=500),
        ),
    ]
