# Generated by Django 4.0.10 on 2023-06-30 10:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0088_alter_characterindustryjob_end_date'),
    ]

    operations = [
        migrations.CreateModel(
            name='HighestSPFilter',
            fields=[
                ('id', models.AutoField(auto_created=True,
                 primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=500)),
                ('description', models.CharField(max_length=500)),
                ('sp_cutoff', models.BigIntegerField(default=5000000000)),
                ('swap_logic', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name': 'Smart Filter: Highest SP Character',
                'verbose_name_plural': 'Smart Filter: Highest SP Character',
            },
        ),
    ]
