# Generated by Django 4.0.2 on 2022-05-01 10:08

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0072_alter_corporationaudit_options'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='miningtaxpaymentcorp',
            name='corp',
        ),
        migrations.DeleteModel(
            name='MiningTax',
        ),
        migrations.DeleteModel(
            name='MiningTaxPaymentCorp',
        ),
    ]
