# Generated by Django 4.0.8 on 2022-12-22 02:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0080_alter_characterlocation_character'),
    ]

    operations = [
        migrations.AddField(
            model_name='characterlocation',
            name='current_ship_name',
            field=models.TextField(
                blank=True, default=None, max_length=150, null=True),
        ),
        migrations.AddField(
            model_name='characterlocation',
            name='current_ship_unique',
            field=models.BigIntegerField(blank=True, default=None, null=True),
        ),
    ]
