.start {
  border-right: 3px dotted;
  padding: 15px;
  margin: 5px;
  width: 325px;
  text-align: right;
}

@media only screen and (max-width: 900px) {
  .start {
    width: 100%;
    border-left: 3px dotted;
    border-right: none;
    text-align: left;
  }
}

.end {
  border-left: 3px dotted;
  padding: 15px;
  margin: 5px;
  width: 325px;
  text-align: left;
}

@media only screen and (max-width: 900px) {
  .end {
    width: 100%;
    border-right: 3px dotted;
    border-left: none;
    text-align: right;
  }
}

.gateActive {
  border-color: aqua !important;
}

.gateInactive {
  border-color: red !important;
}

.gateUnknown {
  border-color: orange !important;
}

.linkLine {
  border-top: 2px dashed grey;
  margin: 0px 20px 0px 20px;
}

.bridgeDiv {
  margin: 15px;
}
